@@ -11,20 +11,31 @@
    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef AROS
+#include "aros_compat.h"
+#endif
 
 #ifdef WIN32
 #include "win32_compat.h"
 #else
-#include <unistd.h>
 #include <strings.h>
 #endif/*WIN32*/
 #define _GNU_SOURCE
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
 #include <stdlib.h>
 #include <assert.h>
+#include <time.h>
 #include "slist.h"
 #include "libnfs-zdr.h"
 #include "libnfs.h"
@@ -34,6 +45,7 @@
 struct rpc_context *rpc_init_context(void)
 {
 	struct rpc_context *rpc;
+	static uint32_t salt = 0;
 
 	rpc = malloc(sizeof(struct rpc_context));
 	if (rpc == NULL) {
@@ -59,7 +71,8 @@ struct rpc_context *rpc_init_context(void)
 		free(rpc);
 		return NULL;
 	}
-	rpc->xid = 1;
+	rpc->xid = salt + time(NULL);
+	salt += 0x01000000;
 	rpc->fd = -1;
 
 	return rpc;
@@ -195,11 +208,7 @@ void rpc_destroy_context(struct rpc_context *rpc)
 	rpc->auth =NULL;
 
 	if (rpc->fd != -1) {
-#if defined(WIN32)
-		closesocket(rpc->fd);
-#else
  		close(rpc->fd);
-#endif
 	}
 
 	if (rpc->encodebuf != NULL) {
