@@ -17,28 +17,45 @@
 /*
  * High level api to nfs filesystems
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef AROS
+#include "aros_compat.h"
+#endif
+
 #ifdef WIN32
 #include "win32_compat.h"
-#define DllExport
 #else
 #include <strings.h>
-#include <unistd.h>
-#ifndef ANDROID
-#include <sys/statvfs.h>
-#else
-#include <netinet/in.h>
-#include <sys/vfs.h>
-#define statvfs statfs
-#endif
-#include <poll.h>
-#include <sys/ioctl.h>
 #include <netdb.h>
 #include <sys/socket.h>
 #include <net/if.h>
+#endif /*WIN32*/
+
+#ifdef ANDROID
+#define statvfs statfs
 #endif
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
+#ifdef HAVE_SYS_VFS_H
+#include <sys/vfs.h>
+#endif
+
+#ifdef HAVE_SYS_STATVFS_H
+#include <sys/statvfs.h>
+#endif
+
+#ifdef HAVE_SYS_IOCTL_H
+#include <sys/ioctl.h>
+#endif
+
+#ifdef HAVE_POLL_H
+#include <poll.h>
+#endif
+
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
 #endif
 
 #include <stdio.h>
@@ -48,6 +65,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <netinet/in.h>
 #include <errno.h>
 
 #ifdef HAVE_SYS_SOCKIO_H
