@@ -22,7 +22,6 @@ THE SOFTWARE.
 */
 /*Adaptions by memphiz@xbmc.org*/
 
-#ifdef WIN32
 #ifndef win32_COMPAT_H_
 #define win32_COMPAT_H_
 #define NO_IPv6 1
@@ -95,6 +94,9 @@ struct pollfd {
 };
 #endif
 
+#define close closesocket
+#define ioctl ioctlsocket
+
 /* Wrapper macros to call misc. functions win32 is missing */
 #define poll(x, y, z)        win32_poll(x, y, z)
 #define inet_pton(x,y,z)     win32_inet_pton(x,y,z)
@@ -102,5 +104,7 @@ int     win32_inet_pton(int af, const char * src, void * dst);
 int     win32_poll(struct pollfd *fds, unsigned int nfsd, int timeout);
 int     win32_gettimeofday(struct timeval *tv, struct timezone *tz);
 
+#define DllExport
+#define HAVE_POLL_H
+
 #endif//win32_COMPAT_H_
-#endif//WIN32
